@@ -189,28 +189,28 @@ genBaseWorkbook <- function() {
   # workbookProtection
 
   list(
-    fileVersion = NULL,
-    fileSharing = NULL,
-    workbookPr = '<workbookPr date1904="false"/>',
-    alternateContent = NULL,
-    revisionPtr = NULL,
-    absPath = NULL, # "x15ac:absPath"
-    workbookProtection = NULL,
-    bookViews = NULL,
-    sheets = NULL,
-    functionGroups = NULL,
-    externalReferences = NULL,
-    definedNames = NULL,
-    calcPr = NULL,
-    oleSize = NULL,
+    fileVersion         = NULL,
+    fileSharing         = NULL,
+    workbookPr          = '<workbookPr date1904="false"/>',
+    alternateContent    = NULL,
+    revisionPtr         = NULL,
+    absPath             = NULL, # "x15ac:absPath"
+    workbookProtection  = NULL,
+    bookViews           = NULL,
+    sheets              = NULL,
+    functionGroups      = NULL,
+    externalReferences  = NULL,
+    definedNames        = NULL,
+    calcPr              = NULL,
+    oleSize             = NULL,
     customWorkbookViews = NULL,
-    pivotCaches = NULL,
-    smartTagPr = NULL,
-    smartTagTypes = NULL,
-    webPublishing = NULL,
-    fileRecoveryPr = NULL,
-    webPublishObjects = NULL,
-    extLst = NULL
+    pivotCaches         = NULL,
+    smartTagPr          = NULL,
+    smartTagTypes       = NULL,
+    webPublishing       = NULL,
+    fileRecoveryPr      = NULL,
+    webPublishObjects   = NULL,
+    extLst              = NULL
   )
 }
 
@@ -223,7 +223,7 @@ genBaseStyleSheet <- function(dxfs = NULL, tableStyles = NULL, extLst = NULL) {
   list(
     numFmts = NULL,
 
-    fonts = c('<font><sz val="11"/><color theme="1"/><name val="Calibri"/><family val="2"/><scheme val="minor"/></font>'),
+    fonts = c('<font><sz val="11"/><color theme="1"/><name val="Aptos Narrow"/><family val="2"/><scheme val="minor"/></font>'),
 
     fills = c(
       '<fill><patternFill patternType="none"/></fill>',
@@ -271,51 +271,36 @@ genBasePic <- function(imageNo, next_id) {
     </xdr:pic>', imageNo, imageNo, next_id)
 }
 
+# TODO: make genBaseTheme() a more flexible function that allows further
+# customization, not only the base font, but also colors and theme name.
+
+# Not sure how the panose values below were created. The second byte looks
+# wrong or at least it differs from our panose table.
+# "\x0B", should be written as as "0B" and not as its decimal value "11".
+# For Calibri it was "\x0F" and for this "0F" was the panose value and
+# not "15". Probably it does not matter.
 genBaseTheme <- function() {
+  read_xml(
   stringi::stri_unescape_unicode(
     '<a:theme xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" name="Office Theme">
   <a:themeElements>
   <a:clrScheme name="Office">
-  <a:dk1>
-  <a:sysClr val="windowText" lastClr="000000"/>
-  </a:dk1>
-  <a:lt1>
-  <a:sysClr val="window" lastClr="FFFFFF"/>
-  </a:lt1>
-  <a:dk2>
-  <a:srgbClr val="44546A"/>
-  </a:dk2>
-  <a:lt2>
-  <a:srgbClr val="E7E6E6"/>
-  </a:lt2>
-  <a:accent1>
-  <a:srgbClr val="4472C4"/>
-  </a:accent1>
-  <a:accent2>
-  <a:srgbClr val="ED7D31"/>
-  </a:accent2>
-  <a:accent3>
-  <a:srgbClr val="A5A5A5"/>
-  </a:accent3>
-  <a:accent4>
-  <a:srgbClr val="FFC000"/>
-  </a:accent4>
-  <a:accent5>
-  <a:srgbClr val="5B9BD5"/>
-  </a:accent5>
-  <a:accent6>
-  <a:srgbClr val="70AD47"/>
-  </a:accent6>
-  <a:hlink>
-  <a:srgbClr val="0563C1"/>
-  </a:hlink>
-  <a:folHlink>
-  <a:srgbClr val="954F72"/>
-  </a:folHlink>
+  <a:dk1><a:sysClr val="windowText" lastClr="000000"/></a:dk1>
+  <a:lt1><a:sysClr val="window" lastClr="FFFFFF"/></a:lt1>
+  <a:dk2><a:srgbClr val="0E2841"/></a:dk2>
+  <a:lt2><a:srgbClr val="E8E8E8"/></a:lt2>
+  <a:accent1><a:srgbClr val="156082"/></a:accent1>
+  <a:accent2><a:srgbClr val="E97132"/></a:accent2>
+  <a:accent3><a:srgbClr val="196B24"/></a:accent3>
+  <a:accent4><a:srgbClr val="0F9ED5"/></a:accent4>
+  <a:accent5><a:srgbClr val="A02B93"/></a:accent5>
+  <a:accent6><a:srgbClr val="4EA72E"/></a:accent6>
+  <a:hlink><a:srgbClr val="467886"/></a:hlink>
+  <a:folHlink><a:srgbClr val="96607D"/></a:folHlink>
   </a:clrScheme>
   <a:fontScheme name="Office">
   <a:majorFont>
-  <a:latin typeface="Calibri Light" panose="020F0302020204030204"/>
+  <a:latin typeface="Aptos Display" panose="02110004020202020204"/>
   <a:ea typeface=""/>
   <a:cs typeface=""/>
   <a:font script="Jpan" typeface="\\u6e38\\u30b4\\u30b7\\u30c3\\u30af Light"/>
@@ -367,7 +352,7 @@ genBaseTheme <- function() {
   <a:font script="Tfng" typeface="Ebrima"/>
   </a:majorFont>
   <a:minorFont>
-  <a:latin typeface="Calibri" panose="020F0502020204030204"/>
+  <a:latin typeface="Aptos Narrow" panose="02110004020202020204"/>
   <a:ea typeface=""/>
   <a:cs typeface=""/>
   <a:font script="Jpan" typeface="\\u6e38\\u30b4\\u30b7\\u30c3\\u30af"/>
@@ -426,146 +411,69 @@ genBaseTheme <- function() {
   </a:solidFill>
   <a:gradFill rotWithShape="1">
   <a:gsLst>
-  <a:gs pos="0">
-  <a:schemeClr val="phClr">
-  <a:lumMod val="110000"/>
-  <a:satMod val="105000"/>
-  <a:tint val="67000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="50000">
-  <a:schemeClr val="phClr">
-  <a:lumMod val="105000"/>
-  <a:satMod val="103000"/>
-  <a:tint val="73000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="100000">
-  <a:schemeClr val="phClr">
-  <a:lumMod val="105000"/>
-  <a:satMod val="109000"/>
-  <a:tint val="81000"/>
-  </a:schemeClr>
-  </a:gs>
+  <a:gs pos="0"><a:schemeClr val="phClr"><a:lumMod val="110000"/><a:satMod val="105000"/><a:tint val="67000"/></a:schemeClr></a:gs>
+  <a:gs pos="50000"><a:schemeClr val="phClr"><a:lumMod val="105000"/><a:satMod val="103000"/><a:tint val="73000"/></a:schemeClr></a:gs>
+  <a:gs pos="100000"><a:schemeClr val="phClr"><a:lumMod val="105000"/><a:satMod val="109000"/><a:tint val="81000"/></a:schemeClr></a:gs>
   </a:gsLst>
   <a:lin ang="5400000" scaled="0"/>
   </a:gradFill>
   <a:gradFill rotWithShape="1">
   <a:gsLst>
-  <a:gs pos="0">
-  <a:schemeClr val="phClr">
-  <a:satMod val="103000"/>
-  <a:lumMod val="102000"/>
-  <a:tint val="94000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="50000">
-  <a:schemeClr val="phClr">
-  <a:satMod val="110000"/>
-  <a:lumMod val="100000"/>
-  <a:shade val="100000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="100000">
-  <a:schemeClr val="phClr">
-  <a:lumMod val="99000"/>
-  <a:satMod val="120000"/>
-  <a:shade val="78000"/>
-  </a:schemeClr>
-  </a:gs>
+  <a:gs pos="0"><a:schemeClr val="phClr"><a:satMod val="103000"/><a:lumMod val="102000"/><a:tint val="94000"/></a:schemeClr></a:gs>
+  <a:gs pos="50000"><a:schemeClr val="phClr"><a:satMod val="110000"/><a:lumMod val="100000"/><a:shade val="100000"/></a:schemeClr></a:gs>
+  <a:gs pos="100000"><a:schemeClr val="phClr"><a:lumMod val="99000"/><a:satMod val="120000"/><a:shade val="78000"/></a:schemeClr></a:gs>
   </a:gsLst>
   <a:lin ang="5400000" scaled="0"/>
   </a:gradFill>
   </a:fillStyleLst>
   <a:lnStyleLst>
-  <a:ln w="6350" cap="flat" cmpd="sng" algn="ctr">
-  <a:solidFill>
-  <a:schemeClr val="phClr"/>
-  </a:solidFill>
-  <a:prstDash val="solid"/>
-  <a:miter lim="800000"/>
-  </a:ln>
-  <a:ln w="12700" cap="flat" cmpd="sng" algn="ctr">
-  <a:solidFill>
-  <a:schemeClr val="phClr"/>
-  </a:solidFill>
-  <a:prstDash val="solid"/>
-  <a:miter lim="800000"/>
-  </a:ln>
-  <a:ln w="19050" cap="flat" cmpd="sng" algn="ctr">
-  <a:solidFill>
-  <a:schemeClr val="phClr"/>
-  </a:solidFill>
-  <a:prstDash val="solid"/>
-  <a:miter lim="800000"/>
-  </a:ln>
+  <a:ln w="12700" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:prstDash val="solid"/><a:miter lim="800000"/></a:ln>
+  <a:ln w="19050" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:prstDash val="solid"/><a:miter lim="800000"/></a:ln>
+  <a:ln w="25400" cap="flat" cmpd="sng" algn="ctr"><a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:prstDash val="solid"/><a:miter lim="800000"/></a:ln>
   </a:lnStyleLst>
   <a:effectStyleLst>
-  <a:effectStyle>
-  <a:effectLst/>
-  </a:effectStyle>
-  <a:effectStyle>
-  <a:effectLst/>
-  </a:effectStyle>
-  <a:effectStyle>
-  <a:effectLst>
-  <a:outerShdw blurRad="57150" dist="19050" dir="5400000" algn="ctr" rotWithShape="0">
-  <a:srgbClr val="000000">
-  <a:alpha val="63000"/>
-  </a:srgbClr>
-  </a:outerShdw>
-  </a:effectLst>
-  </a:effectStyle>
+  <a:effectStyle><a:effectLst/></a:effectStyle>
+  <a:effectStyle><a:effectLst/></a:effectStyle>
+  <a:effectStyle><a:effectLst><a:outerShdw blurRad="57150" dist="19050" dir="5400000" algn="ctr" rotWithShape="0"><a:srgbClr val="000000"><a:alpha val="63000"/></a:srgbClr></a:outerShdw></a:effectLst></a:effectStyle>
   </a:effectStyleLst>
   <a:bgFillStyleLst>
-  <a:solidFill>
-  <a:schemeClr val="phClr"/>
-  </a:solidFill>
-  <a:solidFill>
-  <a:schemeClr val="phClr">
-  <a:tint val="95000"/>
-  <a:satMod val="170000"/>
-  </a:schemeClr>
-  </a:solidFill>
+  <a:solidFill><a:schemeClr val="phClr"/></a:solidFill><a:solidFill><a:schemeClr val="phClr"><a:tint val="95000"/><a:satMod val="170000"/></a:schemeClr></a:solidFill>
   <a:gradFill rotWithShape="1">
   <a:gsLst>
-  <a:gs pos="0">
-  <a:schemeClr val="phClr">
-  <a:tint val="93000"/>
-  <a:satMod val="150000"/>
-  <a:shade val="98000"/>
-  <a:lumMod val="102000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="50000">
-  <a:schemeClr val="phClr">
-  <a:tint val="98000"/>
-  <a:satMod val="130000"/>
-  <a:shade val="90000"/>
-  <a:lumMod val="103000"/>
-  </a:schemeClr>
-  </a:gs>
-  <a:gs pos="100000">
-  <a:schemeClr val="phClr">
-  <a:shade val="63000"/>
-  <a:satMod val="120000"/>
-  </a:schemeClr>
-  </a:gs>
+  <a:gs pos="0"><a:schemeClr val="phClr"><a:tint val="93000"/><a:satMod val="150000"/><a:shade val="98000"/><a:lumMod val="102000"/></a:schemeClr></a:gs>
+  <a:gs pos="50000"><a:schemeClr val="phClr"><a:tint val="98000"/><a:satMod val="130000"/><a:shade val="90000"/><a:lumMod val="103000"/></a:schemeClr></a:gs>
+  <a:gs pos="100000"><a:schemeClr val="phClr"><a:shade val="63000"/><a:satMod val="120000"/></a:schemeClr></a:gs>
   </a:gsLst>
   <a:lin ang="5400000" scaled="0"/>
   </a:gradFill>
   </a:bgFillStyleLst>
   </a:fmtScheme>
   </a:themeElements>
-  <a:objectDefaults/>
+  <a:objectDefaults>
+  <a:lnDef>
+  <a:spPr/>
+  <a:bodyPr/>
+  <a:lstStyle/>
+  <a:style>
+  <a:lnRef idx="2">
+  <a:schemeClr val="accent1"/>
+  </a:lnRef>
+  <a:fillRef idx="0"><a:schemeClr val="accent1"/></a:fillRef>
+  <a:effectRef idx="1"><a:schemeClr val="accent1"/></a:effectRef>
+  <a:fontRef idx="minor"><a:schemeClr val="tx1"/></a:fontRef>
+  </a:style>
+  </a:lnDef>
+  </a:objectDefaults>
   <a:extraClrSchemeLst/>
   <a:extLst>
   <a:ext uri="{05A4C25C-085E-4340-85A3-A5531E510DB2}">
-  <thm15:themeFamily xmlns:thm15="http://schemas.microsoft.com/office/thememl/2012/main" name="Office Theme" id="{62F939B6-93AF-4DB8-9C6B-D6C7DFDC589F}" vid="{4A3C46E8-61CC-4603-A589-7422A47A8E4A}"/>
+  <thm15:themeFamily xmlns:thm15="http://schemas.microsoft.com/office/thememl/2012/main" name="Office Theme" id="{2E142A2C-CD16-42D6-873A-C26D2A0506FA}" vid="{1BDDFF52-6CD6-40A5-AB3C-68EB2F1E4D0A}"/>
   </a:ext>
   </a:extLst>
   </a:theme>'
-  )
+  ), # stri_unescape_unicode
+  pointer = FALSE
+  ) # read_xml
 }
 
 gen_databar_extlst <- function(guid, sqref, posColor, negColor, values, border, gradient) {
@@ -596,6 +504,15 @@ genSlicerCachesExtLst <- function(i) {
   )
 }
 
+genTimelineCachesExtLst <- function(i) {
+  paste0(
+    '<ext uri=\"{D0CA8CA8-9F24-4464-BF8E-62219DCF47F9}\" xmlns:x15=\"http://schemas.microsoft.com/office/spreadsheetml/2010/11/main\">
+    <x15:timelineCacheRefs>',
+    paste(sprintf('<x15:timelineCacheRef r:id="rId%s"/>', i), collapse = ""),
+    "</x15:timelineCacheRefs></ext>"
+  )
+}
+
 
 colors1_xml <- "<cs:colorStyle xmlns:cs=\"http://schemas.microsoft.com/office/drawing/2012/chartStyle\" xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" meth=\"cycle\" id=\"10\">
 <a:schemeClr val=\"accent1\"/>
