@@ -261,6 +261,48 @@ rowcol_to_dim <- function(row, col) {
   # we will always return something like "A1"
   stringi::stri_join(min_col, min_row)
 }
+
+#' consecutive range in vector
+#' @param x integer vector
+#' @keywords internal
+con_rng <- function(x) {
+  if (length(x) == 0) return(NULL)
+  group <- cumsum(c(1, diff(x) != 1))
+
+  # Extract the first and last element of each group using tapply
+  ranges <- tapply(x, group, function(y) c(beg = y[1], end = y[length(y)]))
+  ranges_df <- do.call(rbind, ranges)
+
+  as.data.frame(ranges_df)
+}
+
+#' create consecutive dims from column and row vector
+#' @param cols,rows integer vectors
+#' @keywords internal
+con_dims <- function(cols, rows) {
+
+  c_cols <- con_rng(cols)
+  c_rows <- con_rng(rows)
+
+  c_cols$beg <- int2col(c_cols$beg)
+  c_cols$end <- int2col(c_cols$end)
+
+  dims_cols <- paste0(c_cols$beg, "%s:", c_cols$end, "%s")
+
+  out <- NULL
+  for (i in seq_along(dims_cols)) {
+    for (j in seq_len(nrow(c_rows))) {
+      beg_row <- c_rows[j, "beg"]
+      end_row <- c_rows[j, "end"]
+
+      dims <- sprintf(dims_cols[i], beg_row, end_row)
+      out <- c(out, dims)
+    }
+  }
+
+  paste0(out, collapse = ",")
+}
+
 check_wb_dims_args <- function(args, select = NULL) {
   select <- match.arg(select, c("x", "data", "col_names", "row_names"))
 
@@ -405,11 +447,29 @@ determine_select_valid <- function(args, select = NULL) {
   )
 
   if (isFALSE(valid_cases[[select]])) {
-    stop(
-      "You provided a bad value to `select` in `wb_dims()`.\n ",
-      "Please review. see `?wb_dims`.",
-      call. = FALSE
-    )
+
+    if (isFALSE(args$row_names %||% FALSE) && identical(select, "row_names")) {
+      # If the default for row_names ever changes in openxlsx2, this would need adjustment.
+      stop(
+        "`select` can't be \"row_names\" if `x` doesn't have row names.\n",
+        "Use `row_names = TRUE` inside `wb_dims()` to ensure row names are preserved.",
+        call. = FALSE
+        )
+    } else if (isFALSE(args$col_names %||% TRUE) && identical(select, "col_names")) {
+      # If the default for col_names ever changes in openxlsx2, this would need adjustment.
+      stop(
+        "`select` can't be \"col_names\" if `x` doesn't have column names.\n",
+        "Use `col_names = TRUE` inside `wb_dims()` to ensure column names are preserved.",
+        call. = FALSE
+      )
+    } else {
+      # this is probably redundant now?
+      stop(
+        "You provided a bad value to `select` in `wb_dims()`.\n ",
+        "Please review. see `?wb_dims`.",
+        call. = FALSE
+      )
+    }
   }
 
   select
