@@ -112,7 +112,6 @@ wb_load <- function(
   }
 
   ## Not used
-  # .relsXML          <- grep_xml("_rels/.rels$")
   ContentTypesXML   <- grep_xml("\\[Content_Types\\].xml$")
 
   if (length(ContentTypesXML) == 0 && !debug) {
@@ -120,11 +119,14 @@ wb_load <- function(
     stop(msg)
   }
 
+  # relsXML           <- grep_xml("_rels/.rels$")
+
   appXML            <- grep_xml("app.xml$")
   coreXML           <- grep_xml("core.xml$")
   customXML         <- grep_xml("custom.xml$")
 
   customXmlDir      <- grep_xml("customXml/")
+  docMetadataXML    <- grep_xml("docMetadata/")
 
   workbookBIN       <- grep_xml("workbook.bin$")
   workbookXML       <- grep_xml("workbook.xml$")
@@ -198,6 +200,10 @@ wb_load <- function(
   slicerXML         <- grep_xml("slicer[0-9]+.xml$")
   slicerCachesXML   <- grep_xml("slicerCache[0-9]+.xml$")
 
+  ## timelines
+  timelineXML         <- grep_xml("timeline[0-9]+.xml$")
+  timelineCachesXML   <- grep_xml("timelineCache[0-9]+.xml$")
+
   ## VBA Macro
   vbaProject        <- grep_xml("vbaProject\\.bin$")
 
@@ -214,10 +220,11 @@ wb_load <- function(
   file_folders <- unique(basename(dirname(xmlFiles)))
   known <- c(
     basename(xmlDir), "_rels", "charts", "chartsheets", "ctrlProps",
-    "customXml", "docProps", "drawings", "embeddings", "externalLinks",
-    "media", "persons", "pivotCache", "pivotTables", "printerSettings",
-    "queryTables", "richData", "slicerCaches", "slicers", "tables", "theme",
-    "threadedComments", "worksheets", "xl"
+    "customXml", "docMetadata", "docProps", "drawings", "embeddings",
+    "externalLinks", "media", "persons", "pivotCache", "pivotTables",
+    "printerSettings", "queryTables", "richData", "slicerCaches",
+    "slicers", "tables", "theme", "threadedComments", "timelineCaches",
+    "timelines", "worksheets", "xl", "[trash]"
   )
   unknown <- file_folders[!file_folders %in% known]
   # nocov start
@@ -317,6 +324,17 @@ wb_load <- function(
     wb$custom <- read_xml(customXML, pointer = FALSE)
   }
 
+  if (!data_only && length(docMetadataXML)) {
+
+    # rels <- read_xml(relsXML)
+    # rels_df <- rbindlist(xml_attr(rels, "Relationships", "Relationship"))
+
+    if (any(basename2(docMetadataXML) != "LabelInfo.xml"))
+      warning("unknown metadata file found")
+
+    wb$docMetadata <- read_xml(docMetadataXML, pointer = FALSE)
+  }
+
   nSheets <- length(worksheetsXML) + length(chartSheetsXML)
 
   ##
@@ -483,7 +501,16 @@ wb_load <- function(
 
     extLst <- xml_node(workbook_xml, "workbook", "extLst")
     if (!data_only && length(extLst)) {
-      wb$workbook$extLst <- extLst
+
+      # remove GoogleSheets "metadata" binary blob
+      ext <- xml_node(extLst, "extLst", "ext")
+      sel <- which(grepl("GoogleSheets", ext))
+
+      if (length(sel))
+        extLst <- xml_rm_child(extLst, "ext", which = sel)
+
+      if (length(xml_node_name(extLst, "extLst")))
+        wb$workbook$extLst <- extLst
     }
 
     workbookPr <- xml_node(workbook_xml, "workbook", "workbookPr")
@@ -1029,6 +1056,7 @@ wb_load <- function(
       slcrs <- integer()
       table <- integer()
       trcmt <- integer()
+      tmlne <- integer()
       vmldr <- integer()
 
       if (ncol(wb_rels)) {
@@ -1042,6 +1070,7 @@ wb_load <- function(
         slcrs <- wb_rels$tid[wb_rels$typ == "slicer"]
         table <- wb_rels$tid[wb_rels$typ == "table"]
         trcmt <- wb_rels$tid[wb_rels$typ == "threadedComment"]
+        tmlne <- wb_rels$tid[wb_rels$typ == "timeline"]
         vmldr <- wb_rels$tid[wb_rels$typ == "vmlDrawing"]
       }
 
@@ -1054,6 +1083,7 @@ wb_load <- function(
         slicer           = slcrs,
         table            = table,
         threadedComment  = trcmt,
+        timeline         = tmlne,
         vmlDrawing       = vmldr
       )
     }
@@ -1098,6 +1128,44 @@ wb_load <- function(
       wb$workbook$extLst <- xml_node_create("extLst", xml_children = ext)
     }
 
+    ## Timeline -------------------------------------------------------------------------------------
+    if (length(timelineXML)) {
+
+      # maybe these need to be sorted?
+      # timelineXML <- timelineXML[order(nchar(timelineXML), timelineXML)] ???
+
+      wb$timelines <- vapply(timelineXML, read_xml, pointer = FALSE,
+                             FUN.VALUE = NA_character_, USE.NAMES = FALSE)
+
+      ## worksheet_rels Id for timeline will be rId0
+      for (i in seq_along(wb$timelines)) {
+
+        # this will add timelines to Content_Types. Ergo if worksheets with
+        # timelines are removed, the timeline needs to remain in the worksheet
+        wb$append(
+          "Content_Types",
+          sprintf('<Override PartName="/xl/timelines/timeline%s.xml" ContentType="application/vnd.ms-excel.timeline+xml"/>', i)
+        )
+      }
+    }
+
+    ## ---- timelineCaches
+    if (length(timelineCachesXML)) {
+      wb$timelineCaches <- vapply(timelineCachesXML, read_xml, pointer = FALSE,
+                                  FUN.VALUE = NA_character_, USE.NAMES = FALSE)
+
+      for (i in seq_along(wb$timelineCaches)) {
+        wb$append("Content_Types", sprintf('<Override PartName="/xl/timelineCaches/timelineCache%s.xml" ContentType="application/vnd.ms-excel.timelineCache+xml"/>', i))
+        wb$append("workbook.xml.rels", sprintf('<Relationship Id="rId%s" Type="http://schemas.microsoft.com/office/2011/relationships/timelineCache" Target="timelineCaches/timelineCache%s.xml"/>', 2E5 + i, i))
+      }
+
+      # get extLst object. select the timelineCaches and replace it
+      ext_nams <- xml_node_name(wb$workbook$extLst, "extLst", "ext")
+      is_timeline <- which(ext_nams == "x15:timelineCacheRefs")
+      ext <- xml_node(wb$workbook$extLst, "extLst", "ext")
+      ext[is_timeline] <- genTimelineCachesExtLst(2E5 + seq_along(timelineCachesXML))
+      wb$workbook$extLst <- xml_node_create("extLst", xml_children = ext)
+    }
 
     ## Tables --------------------------------------------------------------------------------------
     if (length(tablesXML)) {
