@@ -44,10 +44,10 @@ test_that("group rows", {
     group_rows("Sheet 1", 1:4)
 
   got <- wb$worksheets[[1]]$sheet_data$row_attr$outlineLevel
-  expect_equal(c("1", "1", "1", ""), got)
+  expect_equal(got, c("1", "1", "1", ""))
 
   got <- wb$worksheets[[1]]$sheet_data$row_attr$r
-  expect_equal(c("1", "2", "3", "4"), got)
+  expect_equal(got, c("1", "2", "3", "4"))
 
   wb <- wb_workbook()$
     add_worksheet("Sheet 1")$
@@ -55,10 +55,10 @@ test_that("group rows", {
     group_rows("Sheet 1", 1:4, collapsed = TRUE)
 
   got <- wb$worksheets[[1]]$sheet_data$row_attr$collapsed
-  expect_equal(c("1", "1", "1", "1"), got)
+  expect_equal(got, c("1", "1", "1", "1"))
 
   got <- wb$worksheets[[1]]$sheet_data$row_attr$hidden
-  expect_equal(c("1", "1", "1", ""), got)
+  expect_equal(got, c("1", "1", "1", ""))
 
 })
 
@@ -71,7 +71,7 @@ test_that("grouping levels", {
 
   wb <- wb_workbook()
   wb$add_worksheet("AirPass")
-  wb$add_data("AirPass", t2, rowNames = TRUE)
+  wb$add_data("AirPass", t2, row_names = TRUE)
 
   # lines used for grouping (here: species)
   grp_rows <- list(
@@ -90,7 +90,7 @@ test_that("grouping levels", {
 
   wb <- wb_workbook()
   wb$add_worksheet("AirPass")
-  wb$add_data("AirPass", t2, rowNames = TRUE)
+  wb$add_data("AirPass", t2, row_names = TRUE)
 
   wb$createCols("AirPass", 13)
 
@@ -141,7 +141,7 @@ test_that("ungroup rows", {
 
   wb <- wb_workbook()$
     add_worksheet("Sheet 1")$
-    add_data(x = cbind(rep(NA, 4)), na.strings = NULL, colNames = FALSE)$
+    add_data(x = cbind(rep(NA, 4)), na.strings = NULL, col_names = FALSE)$
     group_rows("Sheet 1", 1:4)$
     ungroup_rows("Sheet 1", 1:4)
 
@@ -214,7 +214,7 @@ test_that("with outlinePr", {
 
   wb <- wb_workbook()
   wb$add_worksheet("AirPass")
-  wb$add_data("AirPass", t2, rowNames = TRUE)
+  wb$add_data("AirPass", t2, row_names = TRUE)
 
   wb$worksheets[[1]]$sheetPr <-
     xml_node_create(
@@ -255,7 +255,8 @@ test_that("hierarchical grouping works", {
     Var2 = c("B", "B", "B", "C", "C", "C", ""),
     Var3 = c("BA", "BB", "", "CA", "CB", "", ""),
     Var4 = c("BA", "BB", "", "CA", "CB", "", ""),
-    Result = c(1, 2, 3, 4, 5, 9, 12)
+    Result = c(1, 2, 3, 4, 5, 9, 12),
+    stringsAsFactors = FALSE
   )
 
   wb <- wb_workbook()$
@@ -278,9 +279,9 @@ test_that("hierarchical grouping works", {
   )
   wb$group_cols(cols = grp_cols)
 
-  exp <- c("", "3", "3", "1", "3", "3", "1", "")
   got <- wb$worksheets[[1]]$sheet_data$row_attr$outlineLevel
-  expect_equal(exp, got)
+  exp <- c("", "3", "3", "1", "3", "3", "1", "")
+  expect_equal(got, exp)
 
   exp <- c(
     "<col min=\"1\" max=\"1\" collapsed=\"0\" hidden=\"0\" outlineLevel=\"3\" width=\"8.43\"/>",
@@ -289,6 +290,5 @@ test_that("hierarchical grouping works", {
     "<col min=\"4\" max=\"4\" collapsed=\"0\" hidden=\"0\" outlineLevel=\"1\" width=\"8.43\"/>",
     "<col min=\"5\" max=\"5\" collapsed=\"0\" width=\"8.43\"/>"
   )
-  got <- wb$worksheets[[1]]$cols_attr
-  expect_equal(exp, got)
+  expect_equal(wb$worksheets[[1]]$cols_attr, exp)
 })
