@@ -6,13 +6,13 @@ test_that("Protect Workbook", {
 
   wb$protect(password = "abcdefghij")
 
-  expect_true(wb$workbook$workbookProtection == "<workbookProtection hashPassword=\"FEF1\" lockStructure=\"0\" lockWindows=\"0\"/>")
+  expect_equal(wb$workbook$workbookProtection, "<workbookProtection hashPassword=\"FEF1\" lockStructure=\"0\" lockWindows=\"0\"/>")
 
 
   # this creates a corrupted workbook:
   # 1) this nulls the reference
   wb$protect(protect = FALSE, password = "abcdefghij", lockStructure = TRUE, lockWindows = TRUE)
-  expect_true(is.null(wb$workbook$workbookProtection))
+  expect_null(wb$workbook$workbookProtection)
 
   # 2) this creates the reference, but at the wrong position (at the end, not at 6)
   wb$protect(password = "abcdefghij", lockStructure = TRUE)
